* 2 Feb 2011
* WH Moore
* Filename: Tand2000GReplicationSPopLogit2Feb11.do
***************************************************

capture log close
clear
clear matrix
set more off
set mem 100m
set matsize 800
cd "C:\Documents and Settings\Will\My Documents\Research\SPopLogit\Infidelity\StataFiles\"
* cd "/home/will/Documents/Research/SPopLogit/Infidelity/StataFiles"

** (C) Load data.  Do this:  local data = "your filepath/your data.dta".
local data = "Tand2000GReplicationData19Jan11.dta"
use `data'

log using "TandG2000ReplicationSPopLogit2Feb11.log", replace


*******************************
* SPopLogit 2nd specification *
*******************************
/*
spoplogit EvStray ///
       THINKSEX NonPermissive P18S WorkOpp Network ATTEND Male Black ///
       EDLEVEL1, ///
       g(FRANK ONLOOKR6 SEXLOVE TabooYes)
*/

*******************************
* SPopLogit 3rd specification *
*******************************
/*
spoplogit EvStray ///
       THINKSEX NonPermissive P18S WorkOpp Network ATTEND Male Black ///
       EDLEVEL1, ///
       g(FRANK ONLOOKR6 SEXLOVE TabooYes HAPPY GUILTSEX)
*/


/*#############################*/
/* SPopLogit 1st Specifciation */
/*#############################*/

spoplogit EvStray ///
       THINKSEX NonPermissive P18S WorkOpp Network ATTEND Male Black ///
       EDLEVEL1, ///
       g(FRANK ONLOOKR6 SEXLOVE EVPAIDSX JAIL ABORT STDyes)


/*###################*/
/* Calculate Qs of I */
/*###################*/


/*##########################*/
/* Predicted Probabilities  */
/*##########################*/

** (C) Draw simulated coefficients for the model.
preserve
drawnorm b1 b2 b3 b4 b5 b6 b7 b8 b9 b0 g1 g2 g3 g4 g5 g6 g7 g0, n(1000) means(e(b)) cov(e(V)) clear
	tempfile sim_coeffs
	save `sim_coeffs', replace

** Calculate predicted probabilities and confidence intervals for
** each observation in the master dataset and save them to a temporary
** results dataset.
	tempname memhold
	tempfile results

	postfile `memhold' n pr_cheat lci_cheat uci_cheat pr_honest lci_honest uci_honest using `results'

	local N = _N
	forvalues n = 1(1)`N' {
		use `data', clear

		** (C) Pull x values from observation i.
			scalar THINKSEX      = THINKSEX[`n'] //
			scalar NonPermissive = NonPermissive[`n'] //
			scalar P18S          = P18S[`n'] //
			scalar WorkOpp       = WorkOpp[`n'] //
			scalar Network       = Network[`n'] //
			scalar ATTEND        = ATTEND[`n'] //
			scalar Male          = Male[`n'] //
			scalar Black         = Black[`n'] //
			scalar EDLEVEL1      = EDLEVEL1[`n'] //
			scalar FRANK         = FRANK[`n'] //
			scalar ONLOOKR6      = ONLOOKR6[`n'] //
			scalar SEXLOVE       = SEXLOVE[`n'] //
			scalar EVPAIDSX      = EVPAIDSX[`n'] //
			scalar JAIL          = JAIL[`n'] //
			scalar ABORT         = ABORT[`n'] //
			scalar STDyes        = STDyes[`n'] //

			use `sim_coeffs', clear

		** (C) Calculate predicted probabilities.
			gen pr_cheat = invlogit(b0 + b1*scalar(THINKSEX) + b2*scalar(NonPermissive) ///
                        + b3*scalar(P18S) + b4*scalar(WorkOpp) + b5*scalar(Network) ///
                        + b6*scalar(ATTEND) + b7*scalar(Male) + b8*scalar(Black) ///
                        + b9*scalar(EDLEVEL1)) //

			gen pr_honest = invlogit(g0 + g1*scalar(FRANK) + g2*scalar(ONLOOKR6) + ///
                        g3*scalar(SEXLOVE) + g4*scalar(EVPAIDSX) + g5*scalar(JAIL) + ///
                        g6*scalar(ABORT) + g7*scalar(STDyes)) //

		** Get mean predicted probability and confidence intervals
		** for observation i.
			qui sum pr_cheat, meanonly
			scalar pr_cheat = r(mean)
			_pctile pr_cheat, p(5 95)
			scalar lci_cheat = r(r1)
			scalar uci_cheat = r(r2)

			qui sum pr_honest, meanonly
			scalar pr_honest = r(mean)
			_pctile pr_honest, p(5 95)
			scalar lci_honest = r(r1)
			scalar uci_honest = r(r2)

		drop pr_cheat pr_honest
		post `memhold' (`n') ///
			(scalar(pr_cheat)) (scalar(lci_cheat)) (scalar(uci_cheat)) ///
			(scalar(pr_honest)) (scalar(lci_honest)) (scalar(uci_honest))
		}

	postclose `memhold'

** Merge the results back into the (master) data.
	use `data', clear
	gen n = _n
	merge 1:1 n using `results', nogenerate
	drop n

	label var pr_cheat "Pred. prob. Cheat in beta eq"
	label var lci_cheat "Lower 5th centile (90% CI)"
	label var uci_cheat "Upper 5th centile (90% CI)"
	label var pr_honest "Pred. prob. Honest in gamma eq"
	label var lci_honest "Lower 5th centile (90% CI)"
	label var uci_honest "Upper 5th centile (90% CI)"

/* Honest: pr_honest
   Cheated: pr_cheat
   Cheated Honest: pr_cheat * pr_honest
   Cheated Lied: pr_cheat * (1-pr_honest)
   Faithful Honest: (1-pr_cheat) * pr_honest
   Faithful Would Lie: (1-pr_cheat) * (1-pr_honest)  */

sum pr_honest pr_cheat, det

gen pr_CheatHonest = pr_cheat * pr_honest
gen pr_CheatLie    = pr_cheat * (1-pr_honest)
gen pr_FFulHonest  = (1-pr_cheat) * pr_honest
gen pr_FFulWdLie   = (1-pr_cheat) * (1-pr_honest)
sum pr_CheatHonest pr_CheatLie pr_FFulHonest pr_FFulWdLie, det



/*###################*/
/* First Differences */
/*###################*/

*preserve
drawnorm b1 b2 b3 b4 b5 b6 b7 b8 b9 b0 g1 g2 g3 g4 g5 g6 g7 g0, n(1000) means(e(b)) cov(e(V)) clear
save simulated_betas.dta, replace


/* These are the modal value for each var among those who claim to have been faithful */

scalar bTHINKSEX = 3
scalar bNonPermissive = 4
scalar bP18S = 1
scalar bWorkOpp = 1
scalar bNetwork = -0.195
scalar bATTEND = 7
scalar bMale = 0
scalar bBlack = 0
scalar bEDLEVEL1 = 3
scalar gFRANK = 1
scalar gONLOOKR6 = 1
scalar gSEXLOVE = 2
scalar gEVPAIDSX = 2
scalar gJAIL = 2
scalar gABORT = 2
scalar gSTDyes = 0


/*
**  First difference in Beta (latent equation).
============================================================================ */

/* Calculate the Baseline Probability */

gen p_EvStrayBLine = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )

gen p_EvStraybline = invlogit(b0 + b1*bTHINKSEX + b2*bNonPermissive ///
               + b3*bP18S + b4*bWorkOpp + b5*bNetwork ///
               + b6*bATTEND + b7*bMale + b8*bBlack ///
               + b9*bEDLEVEL1 )

sum p_EvStrayBLine
sum p_EvStraybline
centile p_EvStrayBLine, c(2.5 97.5)
centile p_EvStraybline, c(2.5 97.5)



/* 1. THINKSEX Change from "< once a month" to "1 - a few times per week" */

gen p_EvStray1 = invlogit(b0 + b1*1 + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*3 + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_ThinkSex = p_EvStray2 - p_EvStray1

sum diff_ThinkSex
centile diff_ThinkSex, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 2. NonPermissive: change from "Always Wrong" to "Wrong Sometimes" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*4 ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*2 ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_NonPerm = p_EvStray2 - p_EvStray1

sum diff_NonPerm
centile diff_NonPerm, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 3. P18S: change from "One partner" to "2 partners" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*1 + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*2 + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_p18s = p_EvStray2 - p_EvStray1

sum diff_p18s
centile diff_p18s, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 4. WorkOpp: change from "Not more than One of Discuss/Touch/Work with others" to "2 of those 3 True" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*0 + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*1 + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_workopp = p_EvStray2 - p_EvStray1

sum diff_workopp
centile diff_workopp, c(2.5 97.5)

drop p_EvStray1 p_EvStray2



/* 5. Network: change from "25th ptile" to "75th ptile" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*-0.55 ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*0.31 ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_network = p_EvStray2 - p_EvStray1

sum diff_network
centile diff_network, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 6. Attend: change from "75th ptile: Weekly" to "25th ptile: 2x/year" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*2 + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*7 + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_attend = p_EvStray2 - p_EvStray1

sum diff_attend
centile diff_attend, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 7. Male: change from "Female" to "Male" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*0 + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*1 + b8*scalar(bBlack) ///
               + b9*scalar(bEDLEVEL1) )
gen diff_male = p_EvStray2 - p_EvStray1

sum diff_male
centile diff_male, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 8. Black: change from "Not Black" to "Black" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*0 ///
               + b9*scalar(bEDLEVEL1) )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*1 ///
               + b9*scalar(bEDLEVEL1) )
gen diff_black = p_EvStray2 - p_EvStray1

sum diff_black
centile diff_black, c(2.5 97.5)

drop p_EvStray1 p_EvStray2


/* 9. EdLevel: change from "25th ptile: High School" to "75th ptile: Some College" */

gen p_EvStray1 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*2 )
gen p_EvStray2 = invlogit(b0 + b1*scalar(bTHINKSEX) + b2*scalar(bNonPermissive) ///
               + b3*scalar(bP18S) + b4*scalar(bWorkOpp) + b5*scalar(bNetwork) ///
               + b6*scalar(bATTEND) + b7*scalar(bMale) + b8*scalar(bBlack) ///
               + b9*3 )
gen diff_edlevel = p_EvStray2 - p_EvStray1

sum diff_edlevel
centile diff_edlevel, c(2.5 97.5)

drop p_EvStray1 p_EvStray2



/*
**  First difference in Gamma (splitting equation).
============================================================================ */

/* Calculate the Baseline Probability for Gamma */

gen p_splitBLine = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )

sum p_splitBLine, det
centile p_splitBLine, c(2.5 97.5)


/* 1. FRANK: change from "Entirely" to "Mostly" */

gen p_split1 = invlogit(g0 + g1*1 + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*2 + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen diff_frank = p_split2 - p_split1

sum diff_frank
centile diff_frank, c(2.5 97.5)

drop p_split1 p_split2


/* 2. ONLOOKR6: change from "Yes" to "No" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*1 + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*2 + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen diff_onlookr = p_split2 - p_split1

sum diff_onlookr
centile diff_onlookr, c(2.5 97.5)

drop p_split1 p_split2


/* 3. SEXLOVE: change from "Agree" to "Disagree" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*1 + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*2 + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen diff_sexlove = p_split2 - p_split1

sum diff_sexlove
centile diff_sexlove, c(2.5 97.5)

drop p_split1 p_split2


/* 4. EVPAIDSEX: change from "No" to "Yes" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*2 + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*1 + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen diff_evpaidsex = p_split2 - p_split1

sum diff_evpaidsex
centile diff_evpaidsex, c(2.5 97.5)

drop p_split1 p_split2


/* 5. JAIL: change from "No" to "Yes" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*2 + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*1 + g6*scalar(gABORT) + g7*scalar(gSTDyes) )
gen diff_jail = p_split2 - p_split1

sum diff_jail
centile diff_jail, c(2.5 97.5)

drop p_split1 p_split2


/* 6. ABORT: change from "No" to "Yes" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*2 + g7*scalar(gSTDyes) )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*1 + g7*scalar(gSTDyes) )
gen diff_abort = p_split2 - p_split1

sum diff_abort
centile diff_abort, c(2.5 97.5)

drop p_split1 p_split2


/* 7. STDyes: change from "No" to "Yes" */

gen p_split1 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*0 )
gen p_split2 = invlogit(g0 + g1*scalar(gFRANK) + g2*scalar(gONLOOKR6) + g3*scalar(gSEXLOVE) + g4*scalar(gEVPAIDSX) + g5*scalar(gJAIL) + g6*scalar(gABORT) + g7*1 )
gen diff_stdyes = p_split2 - p_split1

sum diff_stdyes
centile diff_stdyes, c(2.5 97.5)

drop p_split1 p_split2

scalar drop _all


******************
log close
exit
******************


************************************
* Estimate a Bivariate Probit Model*
************************************

biprobit (EvStray = ///
       THINKSEX NonPermissive P18S WorkOpp Network ATTEND Male Black ///
       EDLEVEL1) ///
       (EvStrayDup = FRANK ONLOOKR6 SEXLOVE TabooYes HAPPY GUILTSEX), ///
       partial difficult tech(nr 20 bhhh 20) iter(75)

*** NB: Iterations constrained to 75 b/c the model will not converge


********************************************
* Estimate a Bivariate Probit Model, Rho=0 *
********************************************

gen EvStrayDup = EvStray
* Constrain Rho=0
constraint 1  [athrho]_cons = 0
biprobit (EvStray = ///
       THINKSEX NonPermissive P18S WorkOpp Network ATTEND Male Black ///
       EDLEVEL1) ///
       (EvStrayDup = FRANK ONLOOKR6 SEXLOVE TabooYes HAPPY GUILTSEX), ///
       partial difficult tech(nr 20 bhhh 20) iter(75) constraint(1)

*** NB: Iterations constrained to 75 b/c the model will not converge

