** Split Population Logit
** Predicted probabilities in unobserved y and modifying equations.
** 01/2011
** Andreas Beger, Jacqueline H.R. Demeritt, Wonjae Hwang, and Will H. Moore


** To make this file work for your model, change the code in the sections
** marked with (C) to fit your model equation and variable names.
** Specific lines you need to change are marked with two slashes (//) at
** the end.

** (C) Load data.  Do this:  local data = "your filepath/your data.dta".
local data = "Simulations/fakedata.dta" //
use `data'

** (C) Specify and estimate spoplogit model.
spoplogit yobs_orig v1 v2, g(v3) //

** (C) Draw simulated coefficients for the model.
	drawnorm b1 b2 b0 g1 g0, n(1000) means(e(b)) cov(e(V)) clear //
	tempfile sim_betas
	save `sim_betas'

** Calculate predicted probabilities and confidence intervals for
** each observation in the master dataset and save them to a temporary
** results dataset.
	tempname memhold
	tempfile results

	postfile `memhold' n pr_ylat lci_ylat uci_ylat pr_mod lci_mod uci_mod using `results'

	local N = _N
	forvalues n = 1(1)`N' {
		use `data', clear

		** (C) Pull x values from observation i.
			scalar v1 = v1[`n'] //
			scalar v2 = v2[`n'] //
			scalar v3 = v3[`n'] //

			use `sim_betas', clear

		** (C) Calculate predicted probabilities.
			gen pr_ylat = invlogit(b1*scalar(v1) + b2*scalar(v2) + b0) //
			gen pr_mod = invlogit(g1*scalar(v3) + g0) //
	
		** Get mean predicted probability and confidence intervals
		** for observation i.
			qui sum pr_ylat, meanonly
			scalar pr_ylat = r(mean)
			_pctile pr_ylat, p(5 95)
			scalar lci_ylat = r(r1)
			scalar uci_ylat = r(r2)

			qui sum pr_mod, meanonly
			scalar pr_mod = r(mean)
			_pctile pr_mod, p(5 95)
			scalar lci_mod = r(r1)
			scalar uci_mod = r(r2)

		drop pr_ylat pr_mod
		post `memhold' (`n') ///
			(scalar(pr_ylat)) (scalar(lci_ylat)) (scalar(uci_ylat)) ///
			(scalar(pr_mod)) (scalar(lci_mod)) (scalar(uci_mod))
		}

	postclose `memhold'

** Merge the results back into the (master) data.
	use `data', clear
	gen n = _n
	merge 1:1 n using `results', nogenerate
	drop n

	label var pr_ylat "Pred. prob. in unobserved y equation"
	label var lci_ylat "Lower 5th centile (90% CI)"
	label var uci_ylat "Upper 5th centile (90% CI)"
	label var pr_mod "Pred. prob. in modifying equation"
	label var lci_mod "Lower 5th centile (90% CI)"
	label var uci_mod "Upper 5th centile (90% CI)"
